saving_factory
=================================================

.. currentmodule:: skchange.costs

.. autofunction:: saving_factory

.. include:: skchange.costs.saving_factory.examples

.. raw:: html

    <div class="clearer"></div>